==> python-dateparser-1.0.0-2-any.pkg.tar.xz: usr/lib/python3.9/site-packages/dateparser/data/date_translation_data/mn.py <==
info = {
    "name": "mn",
    "date_order": "YMD",
    "january": [
        "нэгдүгээр сар",
        "1-р сар"
    ],
    "february": [
        "хоёрдугаар сар",
        "2-р сар"
    ],
    "march": [
        "гуравдугаар сар",
        "3-р сар"
    ],
    "april": [
        "дөрөвдүгээр сар",
        "4-р сар"
    ],
    "may": [
        "тавдугаар сар",
        "5-р сар"
    ],
    "june": [
        "зургадугаар сар",
        "6-р сар"
    ],
    "july": [
        "долдугаар сар",
        "7-р сар"
    ],
    "august": [
        "наймдугаар сар",
        "8-р сар"
    ],
    "september": [
        "есдүгээр сар",
        "9-р сар"
    ],
    "october": [
        "аравдугаар сар",
        "10-р сар"
    ],
    "november": [
        "арван нэгдүгээр сар",
        "11-р сар"
    ],
    "december": [
        "арван хоёрдугаар сар",
        "12-р сар"
    ],
    "monday": [
        "даваа",
        "да"
    ],
    "tuesday": [
        "мягмар",
        "мя"
    ],
    "wednesday": [
        "лхагва",
        "лх"
    ],
    "thursday": [
        "пүрэв",
        "пү"
    ],
    "friday": [
        "баасан",
        "ба"
    ],
    "saturday": [
        "бямба",
        "бя"
    ],
    "sunday": [
        "ням",
        "ня"
    ],
    "am": [
        "үө"
    ],
    "pm": [
        "үх"
    ],
    "year": [
        "жил"
    ],
    "month": [
        "сар"
    ],
    "week": [
        "долоо хоног",
        "7х"
    ],
    "day": [
        "өдөр"
    ],
    "hour": [
        "цаг",
        "ц"
    ],
    "minute": [
        "минут",
        "мин"
    ],
    "second": [
        "секунд",
        "сек"
    ],
    "relative-type": {
        "1 year ago": [
            "өнгөрсөн жил"
        ],
        "0 year ago": [
            "энэ жил"
        ],
        "in 1 year": [
            "ирэх жил"
        ],
        "1 month ago": [
            "өнгөрсөн сар"
        ],
        "0 month ago": [
            "энэ сар"
        ],
        "in 1 month": [
            "ирэх сар"
        ],
        "1 week ago": [
            "өнгөрсөн долоо хоног"
        ],
        "0 week ago": [
            "энэ долоо хоног"
        ],
        "in 1 week": [
            "ирэх долоо хоног"
        ],
        "1 day ago": [
            "өчигдөр"
        ],
        "0 day ago": [
            "өнөөдөр"
        ],
        "in 1 day": [
            "маргааш"
        ],
        "0 hour ago": [
            "энэ цаг"
        ],
        "0 minute ago": [
            "энэ минут"
        ],
        "0 second ago": [
            "одоо"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "(\\d+) жилийн дараа"
        ],
        "\\1 year ago": [
            "(\\d+) жилийн өмнө"
        ],
        "in \\1 month": [
            "(\\d+) сарын дараа"
        ],
        "\\1 month ago": [
            "(\\d+) сарын өмнө"
        ],
        "in \\1 week": [
            "(\\d+) 7х-ийн дараа"
        ],
        "\\1 week ago": [
            "(\\d+) 7х-ийн өмнө"
        ],
        "in \\1 day": [
            "(\\d+) өдрийн дараа",
            "(\\d+) өдөрт"
        ],
        "\\1 day ago": [
            "(\\d+) өдрийн өмнө"
        ],
        "in \\1 hour": [
            "(\\d+) цагийн дараа",
            "(\\d+) ц дараа"
        ],
        "\\1 hour ago": [
            "(\\d+) цагийн өмнө",
            "(\\d+) ц өмнө"
        ],
        "in \\1 minute": [
            "(\\d+) минутын дараа",
            "(\\d+) мин дараа"
        ],
        "\\1 minute ago": [
            "(\\d+) минутын өмнө",
            "(\\d+) мин өмнө"
        ],
        "in \\1 second": [
            "(\\d+) секундын дараа",
            "(\\d+) сек дараа"
        ],
        "\\1 second ago": [
            "(\\d+) секундын өмнө",
            "(\\d+) сек өмнө"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}

==> python-dateparser-1.1.1-1-any.pkg.tar.xz: usr/lib/python3.10/site-packages/dateparser/data/date_translation_data/mn.py <==
info = {
    "name": "mn",
    "date_order": "YMD",
    "january": [
        "1-р сар",
        "нэгдүгээр сар"
    ],
    "february": [
        "2-р сар",
        "хоёрдугаар сар"
    ],
    "march": [
        "3-р сар",
        "гуравдугаар сар"
    ],
    "april": [
        "4-р сар",
        "дөрөвдүгээр сар"
    ],
    "may": [
        "5-р сар",
        "тавдугаар сар"
    ],
    "june": [
        "6-р сар",
        "зургадугаар сар"
    ],
    "july": [
        "7-р сар",
        "долдугаар сар"
    ],
    "august": [
        "8-р сар",
        "наймдугаар сар"
    ],
    "september": [
        "9-р сар",
        "есдүгээр сар"
    ],
    "october": [
        "10-р сар",
        "аравдугаар сар"
    ],
    "november": [
        "11-р сар",
        "арван нэгдүгээр сар"
    ],
    "december": [
        "12-р сар",
        "арван хоёрдугаар сар"
    ],
    "monday": [
        "да",
        "даваа"
    ],
    "tuesday": [
        "мя",
        "мягмар"
    ],
    "wednesday": [
        "лх",
        "лхагва"
    ],
    "thursday": [
        "пү",
        "пүрэв"
    ],
    "friday": [
        "ба",
        "баасан"
    ],
    "saturday": [
        "бя",
        "бямба"
    ],
    "sunday": [
        "ня",
        "ням"
    ],
    "am": [
        "үө"
    ],
    "pm": [
        "үх"
    ],
    "year": [
        "жил"
    ],
    "month": [
        "сар"
    ],
    "week": [
        "7х",
        "долоо хоног"
    ],
    "day": [
        "өдөр"
    ],
    "hour": [
        "ц",
        "цаг"
    ],
    "minute": [
        "мин",
        "минут"
    ],
    "second": [
        "сек",
        "секунд"
    ],
    "relative-type": {
        "0 day ago": [
            "өнөөдөр"
        ],
        "0 hour ago": [
            "энэ цаг"
        ],
        "0 minute ago": [
            "энэ минут"
        ],
        "0 month ago": [
            "энэ сар"
        ],
        "0 second ago": [
            "одоо"
        ],
        "0 week ago": [
            "энэ долоо хоног"
        ],
        "0 year ago": [
            "энэ жил"
        ],
        "1 day ago": [
            "өчигдөр"
        ],
        "1 month ago": [
            "өнгөрсөн сар"
        ],
        "1 week ago": [
            "өнгөрсөн долоо хоног"
        ],
        "1 year ago": [
            "өнгөрсөн жил"
        ],
        "in 1 day": [
            "маргааш"
        ],
        "in 1 month": [
            "ирэх сар"
        ],
        "in 1 week": [
            "ирэх долоо хоног"
        ],
        "in 1 year": [
            "ирэх жил"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "(\\d+) өдрийн өмнө"
        ],
        "\\1 hour ago": [
            "(\\d+) ц өмнө",
            "(\\d+) цагийн өмнө"
        ],
        "\\1 minute ago": [
            "(\\d+) мин өмнө",
            "(\\d+) минутын өмнө"
        ],
        "\\1 month ago": [
            "(\\d+) сарын өмнө"
        ],
        "\\1 second ago": [
            "(\\d+) сек өмнө",
            "(\\d+) секундын өмнө"
        ],
        "\\1 week ago": [
            "(\\d+) 7х-ийн өмнө"
        ],
        "\\1 year ago": [
            "(\\d+) жилийн өмнө"
        ],
        "in \\1 day": [
            "(\\d+) өдрийн дараа",
            "(\\d+) өдөрт"
        ],
        "in \\1 hour": [
            "(\\d+) ц дараа",
            "(\\d+) цагийн дараа"
        ],
        "in \\1 minute": [
            "(\\d+) мин дараа",
            "(\\d+) минутын дараа"
        ],
        "in \\1 month": [
            "(\\d+) сарын дараа"
        ],
        "in \\1 second": [
            "(\\d+) сек дараа",
            "(\\d+) секундын дараа"
        ],
        "in \\1 week": [
            "(\\d+) 7х-ийн дараа"
        ],
        "in \\1 year": [
            "(\\d+) жилийн дараа"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
